//
//  GOAppDelegate.m
//  FacebookLogin
//
//  Created by Gabriel O'Flaherty-Chan on 2012-11-11.
//  Copyright (c) 2012 Gabrieloc. All rights reserved.
//

#import "GOAppDelegate.h"

NSString *const FBSessionStateChangedNotification = @"gabrieloc_scrumps:FBSessionStateChangedNotification";

@implementation GOAppDelegate

- (BOOL)application:(UIApplication *)application didFinishLaunchingWithOptions:(NSDictionary *)launchOptions
{
    // Override point for customization after application launch.
    return YES;
}

- (void)applicationDidBecomeActive:(UIApplication *)application
{
    // We need to properly handle activation of the application with regards to SSO
    // (eg. returning from iOS 6.0 authorization dialog or from fast app switching)
    [FBSession.activeSession close];
}

- (void)applicationWillTerminate:(UIApplication *)application
{
    [FBSession.activeSession close];
}

#pragma mark Facebook Authentication
// Callback for session changes

- (void)sessionStateChanged:(FBSession *)session state:(FBSessionState) state error:(NSError *)error
{
    switch (state) {
        case FBSessionStateOpen:
            if (!error) {
                // We have a valid session
                NSLog(@"User session found");
            }
            break;
        case FBSessionStateClosed:
        case FBSessionStateClosedLoginFailed:
            [FBSession.activeSession closeAndClearTokenInformation];
            break;
        default:
            break;
    }
    
    [[NSNotificationCenter defaultCenter] postNotificationName:FBSessionStateChangedNotification object:session];
    
    if (error) {
        UIAlertView *alertView = [[UIAlertView alloc] initWithTitle:@"Error" message:error.localizedDescription delegate:nil cancelButtonTitle:@"OK" otherButtonTitles:nil];
        [alertView show];
    }
}

// Open a Facebook session and optionally show the login UX

- (BOOL)openSessionWithAllowLoginUI:(BOOL)allowLoginUI
{
    NSArray *permissions = [[NSArray alloc] initWithObjects:
                            @"user_location",
                            @"user_birthday",
                            @"user_likes",
                            nil];
    return [FBSession openActiveSessionWithReadPermissions:permissions allowLoginUI:allowLoginUI completionHandler:
            ^(FBSession *session, FBSessionState state, NSError *error) {
                [self sessionStateChanged:session state:state error:error];
            }];
}

// If we have a valid session at the time of openURL call, we handle the Facebook transitions by passing the url argument to handeOpenURL

- (void)closeSession
{
    [FBSession.activeSession closeAndClearTokenInformation];
}

- (BOOL)application:(UIApplication *)application openURL:(NSURL *)url sourceApplication:(NSString *)sourceApplication annotation:(id)annotation
{
    // Attempt to extract a token from the url
    return [FBSession.activeSession handleOpenURL:url];
}

@end

