//
//  GOViewController.m
//  FacebookLogin
//
//  Created by Gabriel O'Flaherty-Chan on 2012-11-11.
//  Copyright (c) 2012 Gabrieloc. All rights reserved.
//

#import "GOViewController.h"
#import "GOAppDelegate.h"

@interface GOViewController ()

@property (strong, nonatomic) IBOutlet UILabel *loginLabel;
@property (nonatomic, strong) IBOutlet UIButton *authButton;
@property (strong, nonatomic) IBOutlet UIActivityIndicatorView *spinner;

@end

@implementation GOViewController

- (void)viewDidLoad
{
    [super viewDidLoad];
    [[NSNotificationCenter defaultCenter] addObserver:self selector:@selector(sessionStateChanged:) name:FBSessionStateChangedNotification object:nil];
    
    // Check the sesion for a cached token to show the proper authenticated UI.
    // Since this is not user initiated, do not show the login UX
    [(GOAppDelegate*)APP_DELEGATE openSessionWithAllowLoginUI:NO];
}

- (void)didReceiveMemoryWarning
{
    [super didReceiveMemoryWarning];
    [[NSNotificationCenter defaultCenter] removeObserver:self];
}

- (IBAction)authButtonAction:(id)sender {
    GOAppDelegate *appDelegate = [[UIApplication sharedApplication] delegate];
    
    // If the user is authenticated, log out when the button is clicked.
    // If the user is not authenticated, log in when the button is clicked.
    if (FBSession.activeSession.isOpen) {
        [appDelegate closeSession];
    } else {
        // The user has initiated a login, so call the openSession method + show the login UX
        [appDelegate openSessionWithAllowLoginUI:YES];
    }
}

- (void)sessionStateChanged:(NSNotification *)notification {
    if (FBSession.activeSession.isOpen) {
        [self.authButton setTitle:@"Logout" forState:UIControlStateNormal];
        [self.spinner startAnimating];
        
        [FBRequestConnection startForMeWithCompletionHandler:^(FBRequestConnection *connection, id<FBGraphUser> user, NSError *error) {
            [self.spinner stopAnimating];
            if (!error) {
                NSString *userInfo = @"";
                // Example: typed access (name)
                // - no special permission required
                userInfo = [userInfo stringByAppendingString: [NSString stringWithFormat:@"Name: %@\n\n", user.name]];
                
                // Example: typed access, (birthday)
                // - requires user_birthday permission
                userInfo = [userInfo stringByAppendingString:[NSString stringWithFormat:@"Birthday: %@\n\n", user.birthday]];
                
                // Example: partially typed access, to location field, name key (lcoation)
                // - rewquires user_location permission
                userInfo = [userInfo stringByAppendingString:[NSString stringWithFormat:@"Location: %@\n\n", [user.location objectForKey:@"name"]]];
                
                // Example: access via key (locale)
                // - no special permissions required
                userInfo = [userInfo stringByAppendingString:[NSString stringWithFormat:@"Locale: %@\n\n", [user objectForKey:@"locale"]]];
                
                // Example: access via key for array (languages)
                // - requires user_likes permission
                if ([user objectForKey:@"languages"]) {
                    NSArray *languages = [user objectForKey:@"languages"];
                    NSMutableArray *languagesNames = [[NSMutableArray alloc] init];
                    for (int i = 0; i < [languages count]; i++) {
                        [languagesNames addObject:[[languages objectAtIndex:i] objectForKey:@"name"]];
                    }
                    userInfo = [userInfo stringByAppendingString:[NSString stringWithFormat:@"Languages: %@\n\n", languagesNames]];
                }
                
                // Display the user info
                NSLog(@"%@", userInfo);
                
                self.loginLabel.text = [NSString stringWithFormat:@"Logged into iOS as %@", user.name];
            }
        }];
    } else {
        [self.spinner stopAnimating];
        [self.authButton setTitle:@"Login to Facebook" forState:UIControlStateNormal];
        self.loginLabel.text = @"Not Logged in";
    }
}

@end
